@@ -37,7 +37,7 @@ dummy = [
 
 swing = [
 	ChordInstrument({'channel':7, 'chance': 0.15, 'max_velocity': 70}), 
-	SlowStridePianist({'max_velocity': 80}),
+	SlowStridePianist({'channel': 2, 'max_velocity': 80}),
 	RockDrum({'start': 0}),
 	SoloInstrument({'channel':11, 'midi_instr': 66, 'start': 0, 'step': 4}),
 	SoloInstrument({'channel':12, 'midi_instr': 11, 'start': 4, 'step': 4}),
@@ -131,3 +131,9 @@ jazz_battle = [
 	SoloInstrument({'channel':12, 'midi_instr': 66, 'start': 0, 'step': 1, 'chance': 0.7}),
 	SoloInstrument({'channel':13, 'midi_instr': 11, 'start': 8, 'step': 4, 'chance': 0.7}),
 	]
+
+midi_test = [
+	RockDrum({'start': 0, 'step': 1}),
+	SimpleChordInstrument({'start':1, 'midi_inst': 1, 'channel': 1}),
+
+	]
