@@ -9,10 +9,10 @@ class Block:
 	bpm = 120
 	resolution = 8
 	meter = (4,4)
-	duration = 2
+	duration = 1
 
 	swing = True
-	key = 'A'
+	key = 'C'
 	instruments = []
 
 	wildness = 0.5
